Module cli

Module cli 

this module defines the command line interface for the application

Modules

args
cmd
the subcommands for the CLI application

Structs

Cli
The root command line interface structure
ConnectCmd

Enums

Command
ConnectOpts

Functions

cli
a helper function used to load, or parse, the command line interface from the arguments