pub enum LogLevel {
Debug,
Error,
Info,
Trace,
Warn,
Off,
}Expand description
The LogLevel implementation is a custom enumeration of compatible logging levels for the
application, providing options for debug, error, info, trace, warn, and off levels. this is
primarily done to ensure proper serialization and deserialization within configuration
files.
Variants
Implementations
Sourceimpl LogLevel
impl LogLevel
Sourcepub const fn is_debug(&self) -> bool
pub const fn is_debug(&self) -> bool
Returns true if the enum is LogLevel::Debug otherwise false
Sourcepub const fn is_error(&self) -> bool
pub const fn is_error(&self) -> bool
Returns true if the enum is LogLevel::Error otherwise false
Sourceimpl LogLevel
impl LogLevel
Sourcepub fn from_tracing_level(level: Level) -> Self
pub fn from_tracing_level(level: Level) -> Self
Converts a tracing::Level to a LogLevel
Sourcepub fn from_level_filter(filter: LevelFilter) -> Self
pub fn from_level_filter(filter: LevelFilter) -> Self
Converts a LevelFilter to a LogLevel
pub fn as_tracing_level(&self) -> Option<Level>
pub fn as_level_filter(&self) -> LevelFilter
pub fn as_env_filter(&self, name: &str) -> EnvFilter
pub fn fmt_as_env_filter(&self, name: &str) -> String
pub fn init_tracing(&self, name: &str)