pub struct DatabaseConfig {
pub max_connections: u32,
pub pool_size: u32,
pub url: DatabaseLink,
}Fields
max_connections: u32pool_size: u32url: DatabaseLinkImplementations
Sourceimpl DatabaseConfig
impl DatabaseConfig
pub fn new() -> Self
Sourcepub const fn max_connections(&self) -> u32
pub const fn max_connections(&self) -> u32
returns the maximum number of connections
Sourcepub fn url(&self) -> DatabaseUrl
pub fn url(&self) -> DatabaseUrl
returns a reference to the database url
Sourcepub fn with_max_connections(self, max_connections: u32) -> Self
pub fn with_max_connections(self, max_connections: u32) -> Self
consumes the instance to create another with the given maximum number of connections
Sourcepub fn with_pool_size(self, pool_size: u32) -> Self
pub fn with_pool_size(self, pool_size: u32) -> Self
consumes the instance to create another with the given pool size
pub fn with_url(self, url: DatabaseLink) -> Self
Sourcepub fn set_max_connections(&mut self, max_connections: u32)
pub fn set_max_connections(&mut self, max_connections: u32)
update the configured maximum number of connections
Sourcepub fn set_pool_size(&mut self, pool_size: u32)
pub fn set_pool_size(&mut self, pool_size: u32)
update the pool size for the database
Sourcepub fn set_url(&mut self, url: DatabaseLink)
pub fn set_url(&mut self, url: DatabaseLink)
update the database url