pub struct NetAddr {
pub host: String,
pub port: u16,
}Fields
host: Stringport: u16Implementations
Sourceimpl NetAddr
impl NetAddr
pub const LOCALHOST: &'static str = "0.0.0.0"
pub const DEFAULT_HOST: &'static str = "0.0.0.0"
pub const DEFAULT_PORT: u16 = 8_080u16
Sourcepub fn new<H>(host: H, port: u16) -> Selfwhere
H: ToString,
pub fn new<H>(host: H, port: u16) -> Selfwhere
H: ToString,
initialize a new instance of the network address from the given components
pub fn from_ip_with_port(ip: IpAddr, port: u16) -> Self
Sourcepub fn from_socket_addr(addr: SocketAddr) -> Self
pub fn from_socket_addr(addr: SocketAddr) -> Self
convert the given socket address into a valid network address
Sourcepub fn localhost(port: u16) -> Self
pub fn localhost(port: u16) -> Self
initialize a new instance of the network address bound to localhost and the given port
Sourcepub fn as_socket_addr(&self) -> SocketAddr
pub fn as_socket_addr(&self) -> SocketAddr
convert a reference of the network address into a SocketAddr
Sourcepub async fn bind(&self) -> Result<TcpListener>
pub async fn bind(&self) -> Result<TcpListener>
initialize a new listener, bound to the configured address