pub struct NetworkConfig { /* private fields */ }Implementations
Sourceimpl NetworkConfig
impl NetworkConfig
pub fn new() -> Self
Sourcepub const fn address_mut(&mut self) -> &mut NetAddr
pub const fn address_mut(&mut self) -> &mut NetAddr
returns a mutable reference to the address
Sourcepub const fn max_connections(&self) -> u16
pub const fn max_connections(&self) -> u16
returns the maximum number of connections
Sourcepub const fn max_connections_mut(&mut self) -> &mut u16
pub const fn max_connections_mut(&mut self) -> &mut u16
returns a mutable reference to the maximum number of connections
Sourcepub fn should_open(self) -> Self
pub fn should_open(self) -> Self
consumes the current instance to create another that should open by default
Sourcepub fn should_not_open(self) -> Self
pub fn should_not_open(self) -> Self
consumes the instance to create another that should not open by default
Sourcepub fn with_address(self, address: NetAddr) -> Self
pub fn with_address(self, address: NetAddr) -> Self
consumes the current instance to create another with the given address
Sourcepub fn with_basepath(self, basepath: impl ToString) -> Self
pub fn with_basepath(self, basepath: impl ToString) -> Self
consumes the current instance to create another with the given basepath
Sourcepub fn set_address(&mut self, address: NetAddr)
pub fn set_address(&mut self, address: NetAddr)
update the current address and return a mutable reference to self
Sourcepub fn set_basepath<T>(&mut self, basepath: T)where
T: ToString,
pub fn set_basepath<T>(&mut self, basepath: T)where
T: ToString,
update the current basepath and return a mutable reference to self
Sourcepub const fn set_max_connections(&mut self, max_connections: u16)
pub const fn set_max_connections(&mut self, max_connections: u16)
update the maximum number of connections and return a mutable reference to self
Sourcepub fn as_socket_addr(&self) -> SocketAddr
pub fn as_socket_addr(&self) -> SocketAddr
Returns an instance of the address as a SocketAddr
Sourcepub async fn bind(&self) -> Result<TcpListener>
pub async fn bind(&self) -> Result<TcpListener>
Binds the address to a TcpListener