Scope

Struct Scope 

pub struct Scope { /* private fields */ }
Scope stores critical information regarding the applications current position within the filesystem. The context is considered to be the current working directory of the application while the workdir is used to point to the directory where all of the assets are stored.

Implementations

Source

impl Scope

pub fn from_workdir<T>(workdir: T) -> Self
where T: ToString,

pub fn context(&self) -> Option<&str>

returns a reference to the context of the scope

pub fn context_mut(&mut self) -> Option<&mut String>

returns a mutable reference to the context of the scope

pub fn workdir(&self) -> &str

returns a reference to the workdir

pub fn as_path(&self) -> PathBuf

convert the scope into a PathBuf, automatically including the context if it exists

pub fn as_path_str(&self) -> String

converts the scope into a string

pub fn contextless(self) -> Self

consumes the current instance to ensure no context is present

pub fn set_cwd(&self)

sets the current working directory to the scope

pub fn set_context<T>(&mut self, context: T)
where T: ToString,

sets the context of the scope

pub fn set_workdir<T>(&mut self, workdir: T)
where T: ToString,

update the current workind directory

pub fn display(&self) -> String

returns a string representation of the scope