pub struct ServicesConfig {
pub database: DatabaseConfig,
pub tracing: TracingConfig,
}Fields
database: DatabaseConfigtracing: TracingConfigImplementations
Sourceimpl ServicesConfig
impl ServicesConfig
Sourcepub const fn database(&self) -> &DatabaseConfig
pub const fn database(&self) -> &DatabaseConfig
returns a reference to the database configuration
Sourcepub const fn database_mut(&mut self) -> &mut DatabaseConfig
pub const fn database_mut(&mut self) -> &mut DatabaseConfig
returns a mutable reference to the database configuration
Sourcepub const fn tracing(&self) -> &TracingConfig
pub const fn tracing(&self) -> &TracingConfig
returns a reference to the tracing configuration
Sourcepub const fn tracing_mut(&mut self) -> &mut TracingConfig
pub const fn tracing_mut(&mut self) -> &mut TracingConfig
returns a mutable reference to the tracing configuration
Sourcepub fn set_database(&mut self, database: DatabaseConfig)
pub fn set_database(&mut self, database: DatabaseConfig)
update the database configuration
Sourcepub const fn set_tracing(&mut self, tracing: TracingConfig)
pub const fn set_tracing(&mut self, tracing: TracingConfig)
update the tracing configuration
Sourcepub fn with_database(self, database: DatabaseConfig) -> Self
pub fn with_database(self, database: DatabaseConfig) -> Self
consumes the current instance to set the database configuration
Sourcepub fn with_tracing(self, tracing: TracingConfig) -> Self
pub fn with_tracing(self, tracing: TracingConfig) -> Self
consumes the current instance to set the tracing configuration