pub struct DatabaseUrl {
pub scheme: String,
pub host: String,
pub port: u16,
pub username: String,
pub password: String,
pub database: String,
}Expand description
DatabaseUrl represents a structured database connection URL, providing options for the
scheme, host, port, username, password, and database name.
Fields
scheme: Stringhost: Stringport: u16username: Stringpassword: Stringdatabase: StringImplementations
Sourceimpl DatabaseUrl
impl DatabaseUrl
Sourcepub fn from_url_str<T>(url: T) -> Self
pub fn from_url_str<T>(url: T) -> Self
try to parse an instance from the given url
Sourcepub fn from_env(key: &str) -> Self
pub fn from_env(key: &str) -> Self
load and parse the database url from the configured environment variable
Sourcepub fn set_database<T>(&mut self, database: T)where
T: ToString,
pub fn set_database<T>(&mut self, database: T)where
T: ToString,
update the database name
Sourcepub fn set_username<T>(&mut self, username: T)where
T: ToString,
pub fn set_username<T>(&mut self, username: T)where
T: ToString,
set the username
Sourcepub fn set_password<T>(&mut self, password: T)where
T: ToString,
pub fn set_password<T>(&mut self, password: T)where
T: ToString,
update the database password
Sourcepub fn set_scheme<T>(&mut self, scheme: T)where
T: ToString,
pub fn set_scheme<T>(&mut self, scheme: T)where
T: ToString,
update the scheme of the database
Sourcepub fn with_database<T>(self, database: T) -> Selfwhere
T: ToString,
pub fn with_database<T>(self, database: T) -> Selfwhere
T: ToString,
returns a new instance with the given database name
Sourcepub fn with_host<T>(self, host: T) -> Selfwhere
T: ToString,
pub fn with_host<T>(self, host: T) -> Selfwhere
T: ToString,
returns a new instance with the given host
Sourcepub fn with_username<T>(self, username: T) -> Selfwhere
T: ToString,
pub fn with_username<T>(self, username: T) -> Selfwhere
T: ToString,
returns a new instance with the given username
Sourcepub fn with_password<T>(self, password: T) -> Selfwhere
T: ToString,
pub fn with_password<T>(self, password: T) -> Selfwhere
T: ToString,
returns a new instance with the given password
Sourcepub fn with_scheme<T>(self, scheme: T) -> Selfwhere
T: ToString,
pub fn with_scheme<T>(self, scheme: T) -> Selfwhere
T: ToString,
returns a new instance with the given scheme