pub struct Cli {
pub command: Option<Command>,
pub config: String,
pub release: u8,
pub update: u8,
pub verbose: u8,
}Expand description
The root command line interface structure
Fields
command: Option<Command>config: Stringrelease: u8update: u8verbose: u8Implementations
Sourceimpl Cli
impl Cli
Sourcepub const fn is_release(&self) -> bool
pub const fn is_release(&self) -> bool
returns true if the release flag has been toggled at least once
Sourcepub const fn is_verbose(&self) -> bool
pub const fn is_verbose(&self) -> bool
returns true if the verbose flag has been toggled at least once