pub struct Context { /* private fields */ }Implementations
Sourceimpl Context
impl Context
Sourcepub fn new() -> Self
pub fn new() -> Self
attempts to build the settings from the configured sources, falling back to the default
Sourcepub const fn from_config(settings: Settings) -> Self
pub const fn from_config(settings: Settings) -> Self
initialize a new context from the given configuration
Sourcepub const fn settings(&self) -> &Settings
pub const fn settings(&self) -> &Settings
returns a reference to the Settings of the current context.
Sourcepub fn settings_mut(&mut self) -> &mut Settings
pub fn settings_mut(&mut self) -> &mut Settings
returns a mutable reference to the Settings of the current context.