Settings

Struct Settings 

pub struct Settings {
    pub mode: Mode,
    pub name: String,
    pub network: NetworkConfig,
    pub scope: Scope,
    pub services: ServicesConfig,
    pub version: String,
    pub workspace: WorkspaceConfig,
}

Fields

mode: Modename: Stringnetwork: NetworkConfigscope: Scopeservices: ServicesConfigversion: Stringworkspace: WorkspaceConfig

Implementations

Source

impl Settings

pub const DEFAULT_MODE: Mode = Mode::Debug

pub const APP_NAME: &'static str = "arachnid"

pub fn new() -> Self

attempts to initialize a build a new instance of the configuration, falling back to the logical default if unsuccessful

pub fn from_mode(mode: Mode) -> Self

initialize a new instance of the settings from the given Mode

pub fn debug(self) -> Self

consumes the current instance to create another in Debug mode

pub fn release(self) -> Self

consumes the current instance to create another in Release mode

pub fn build() -> Result<Self, ConfigError>

tries to build the settings from the configuration sources

pub const fn mode(&self) -> Mode

returns a copy of the configured Mode

pub fn name(&self) -> &str

returns a reference to the application name

pub const fn network(&self) -> &NetworkConfig

returns a reference to the network configuration

pub const fn network_mut(&mut self) -> &mut NetworkConfig

returns a mutable reference to the network configuration

pub const fn scope(&self) -> &Scope

returns a reference to the current scope

pub const fn scope_mut(&mut self) -> &mut Scope

returns a mutable reference to the current scope

pub const fn services(&self) -> &ServicesConfig

returns a reference to the services

pub const fn services_mut(&mut self) -> &mut ServicesConfig

returns a mutable reference to the services

pub fn version(&self) -> &str

returns the version of the application

pub const fn workspace(&self) -> &WorkspaceConfig

returns a reference to the workspace

pub const fn workspace_mut(&mut self) -> &mut WorkspaceConfig

returns a mutable reference to the workspace

pub async fn bind(&self) -> Result<TcpListener>

attempts to bind a TcpListener to the configured network address.

pub fn init_tracing(&self)

Initialize tracing modules

pub fn set_workdir<T>(&mut self, workdir: T)
where PathBuf: From<T>,

set the working directory of the scope

pub fn set_workdir_option<T>(&mut self, workdir: Option<T>)
where PathBuf: From<T>,

if the workdir is set, set it to the given workdir

pub fn set_port(&mut self, port: u16)

pub fn set_log_level(&mut self, level: LogLevel)