Crate arachnid_cli

Crate arachnid_cli 

app-specific modules supporting the command line-interface for arachnid

Modules

cli
this module defines the command line interface for the application
config
Configuration
context

Structs

Cli
The root command line interface structure
Context
Settings

Functions

cli
a helper function used to load, or parse, the command line interface from the arguments