this module defines the command line interface for the application
Modules
Structs
- Cli
- The root command line interface structure
- Connect
Cmd
Enums
Functions
- cli
- a helper function used to load, or parse, the command line interface from the arguments