TracingConfig

Struct TracingConfig 

pub struct TracingConfig {
    pub ansi: bool,
    pub file: bool,
    pub level: LogLevel,
    pub line_number: bool,
    pub target: bool,
    pub thread_ids: bool,
    pub thread_names: bool,
    pub timer: bool,
}

Fields

ansi: boolfile: boollevel: LogLevelline_number: booltarget: boolthread_ids: boolthread_names: booltimer: bool

Implementations

Source

impl TracingConfig

pub const fn new(level: LogLevel) -> Self

initialize a new instance of the tracing configuration from the given log level

pub const fn ansi(&self) -> bool

returns true if ansi output is enabled

pub fn file(&self) -> bool

returns true if file output is enabled

pub const fn level(&self) -> LogLevel

returns a copy of the configured log level

pub const fn line_number(&self) -> bool

returns true if the line numbers are enabled

pub const fn target(&self) -> bool

returns true if the target is enabled

pub const fn thread_ids(&self) -> bool

returns true if thread ids are enabled

pub const fn thread_names(&self) -> bool

returns true if thread names are enabled

pub const fn set_ansi(&mut self, ansi: bool) -> &mut Self

update the ansi setting and return a mutable reference to self

pub const fn set_file(&mut self, file: bool) -> &mut Self

set whether to log to file or not

pub const fn set_level(&mut self, level: LogLevel) -> &mut Self

update the log level and return a mutable reference to self

pub const fn set_line_number(&mut self, line_number: bool) -> &mut Self

update if the line number should be displayed

pub const fn set_target(&mut self, target: bool) -> &mut Self

update the target flag and return a mutable reference to self.

pub const fn set_thread_ids(&mut self, thread_ids: bool) -> &mut Self

update the thread ids flag and return a mutable reference to self.

pub const fn set_thread_names(&mut self, thread_names: bool) -> &mut Self

update the thread names flag and return a mutable reference to self.

pub const fn set_timer(&mut self, timer: bool) -> &mut Self

pub fn with_ansi(self, ansi: bool) -> Self

pub fn with_file(self, file: bool) -> Self

pub fn with_level(self, level: LogLevel) -> Self

pub fn with_line_number(self, line_number: bool) -> Self

pub fn with_target(self, target: bool) -> Self

pub fn with_thread_ids(self, thread_ids: bool) -> Self

pub fn with_thread_names(self, thread_names: bool) -> Self

pub fn get_env_filter(&self, name: &str) -> EnvFilter

create an env filter from the current configuration

pub fn init_tracing(&self, name: &str)

Initialize the tracer with the given name